# pytyper

## Description
pytyper is a Python library that provides the user with basic functions that deal with typing and typing tests. A few of many functions include calculating WPM and accuracy.\
Not only does pytyper implement typing calculations, it also implements string modification, comparison, and number formatting.

## Installation
```
pip install pytyper
```

## Usage
A proof-of-concept CLI tool is hosted at:\
https://github.com/greysonDEV/typeshell-cli

## Docu-mini-tation
[pytyper documentation](https://github.com/greysonDEV/pytyper/blob/master/DOCUMENTATION.md)

## License
pytyper is licensed under the [MIT](https://github.com/greysonDEV/pytyper/blob/master/LICENSE) License.
